public inbox for passt-dev@passt.top
 help / color / mirror / code / Atom feed
From: Laurent Vivier <lvivier@redhat.com>
To: passt-dev@passt.top
Cc: Laurent Vivier <lvivier@redhat.com>
Subject: [PATCH v4 06/10] udp: rename udp_sock_handler() to udp_buf_sock_handler()
Date: Fri, 31 May 2024 16:23:40 +0200	[thread overview]
Message-ID: <20240531142344.1420034-7-lvivier@redhat.com> (raw)
In-Reply-To: <20240531142344.1420034-1-lvivier@redhat.com>

We are going to introduce a variant of the function to use
vhost-user buffers rather than passt internal buffers.

Signed-off-by: Laurent Vivier <lvivier@redhat.com>
---
 passt.c | 2 +-
 udp.c   | 6 +++---
 udp.h   | 2 +-
 3 files changed, 5 insertions(+), 5 deletions(-)

diff --git a/passt.c b/passt.c
index a8c4cd3f8820..69a59f1e9b6d 100644
--- a/passt.c
+++ b/passt.c
@@ -365,7 +365,7 @@ loop:
 			tcp_timer_handler(&c, ref);
 			break;
 		case EPOLL_TYPE_UDP:
-			udp_sock_handler(&c, ref, eventmask, &now);
+			udp_buf_sock_handler(&c, ref, eventmask, &now);
 			break;
 		case EPOLL_TYPE_PING:
 			icmp_sock_handler(&c, ref);
diff --git a/udp.h b/udp.h
index 9976b6231f1c..5865def20856 100644
--- a/udp.h
+++ b/udp.h
@@ -9,7 +9,7 @@
 #define UDP_TIMER_INTERVAL		1000 /* ms */
 
 void udp_portmap_clear(void);
-void udp_sock_handler(const struct ctx *c, union epoll_ref ref, uint32_t events,
+void udp_buf_sock_handler(const struct ctx *c, union epoll_ref ref, uint32_t events,
 		      const struct timespec *now);
 int udp_tap_handler(struct ctx *c, uint8_t pif, sa_family_t af,
 		    const void *saddr, const void *daddr,
diff --git a/udp.c b/udp.c
index 4295d48046a6..a13013901e26 100644
--- a/udp.c
+++ b/udp.c
@@ -729,7 +729,7 @@ static void udp_tap_send(const struct ctx *c,
 }
 
 /**
  * udp_sock_handler() - Handle new data from socket
  * @c:		Execution context
  * @ref:	epoll reference
  * @events:	epoll events bitmap
@@ -737,8 +737,8 @@ static void udp_tap_send(const struct ctx *c,
  *
  * #syscalls recvmmsg
  */
-void udp_sock_handler(const struct ctx *c, union epoll_ref ref, uint32_t events,
-		      const struct timespec *now)
+void udp_buf_sock_handler(const struct ctx *c, union epoll_ref ref, uint32_t events,
+			  const struct timespec *now)
 {
 	/* For not entirely clear reasons (data locality?) pasta gets
 	 * better throughput if we receive tap datagrams one at a
@@ -729,7 +729,7 @@ static void udp_tap_send(const struct ctx *c,
 
 /**
- * udp_sock_handler() - Handle new data from socket
+ * udp_buf_sock_handler() - Handle new data from socket
  * @c:		Execution context
  * @ref:	epoll reference
-- 
@@ -9,7 +9,7 @@
 #define UDP_TIMER_INTERVAL		1000 /* ms */
 
 void udp_portmap_clear(void);
-void udp_sock_handler(const struct ctx *c, union epoll_ref ref, uint32_t events,
+void udp_buf_sock_handler(const struct ctx *c, union epoll_ref ref, uint32_t events,
 		      const struct timespec *now);
 int udp_tap_handler(struct ctx *c, uint8_t pif, sa_family_t af,
 		    const void *saddr, const void *daddr,
-- 
2.44.0


  parent reply	other threads:[~2024-05-31 14:23 UTC|newest]

Thread overview: 20+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2024-05-31 14:23 [PATCH v4 00/10] Add vhost-user support to passt (part 2) Laurent Vivier
2024-05-31 14:23 ` [PATCH v4 01/10] tcp: inline tcp_l2_buf_fill_headers() Laurent Vivier
2024-05-31 14:23 ` [PATCH v4 02/10] tcp: extract buffer management from tcp_send_flag() Laurent Vivier
2024-06-01  5:43   ` David Gibson
2024-05-31 14:23 ` [PATCH v4 03/10] tcp: move buffers management functions to their own file Laurent Vivier
2024-06-03  1:27   ` David Gibson
2024-05-31 14:23 ` [PATCH v4 04/10] tap: export pool_flush()/tapX_handler()/packet_add() Laurent Vivier
2024-06-03  1:32   ` David Gibson
2024-05-31 14:23 ` [PATCH v4 05/10] udp: move udpX_l2_buf_t and udpX_l2_mh_sock out of udp_update_hdrX() Laurent Vivier
2024-06-03  2:54   ` David Gibson
2024-05-31 14:23 ` Laurent Vivier [this message]
2024-06-03  4:02   ` [PATCH v4 06/10] udp: rename udp_sock_handler() to udp_buf_sock_handler() David Gibson
2024-05-31 14:23 ` [PATCH v4 07/10] vhost-user: compare mode MODE_PASTA and not MODE_PASST Laurent Vivier
2024-06-03  4:04   ` David Gibson
2024-05-31 14:23 ` [PATCH v4 08/10] iov: remove iov_copy() Laurent Vivier
2024-06-03  4:05   ` David Gibson
2024-05-31 14:23 ` [PATCH v4 09/10] tcp: remove tap_hdr parameter Laurent Vivier
2024-06-03  4:12   ` David Gibson
2024-05-31 14:23 ` [PATCH v4 10/10] tap: use in->buf_size rather than sizeof(pkt_buf) Laurent Vivier
2024-06-03  4:20   ` David Gibson

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20240531142344.1420034-7-lvivier@redhat.com \
    --to=lvivier@redhat.com \
    --cc=passt-dev@passt.top \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://passt.top/passt

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for IMAP folder(s).